@@ -1,7 +1,7 @@
 package Bencher::Scenario::RegexpAssemble;
 
-our $DATE = '2016-02-11'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -61,7 +61,7 @@ Bencher::Scenario::RegexpAssemble - Benchmark Regexp::Assemble
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::RegexpAssemble (from Perl distribution Bencher-Scenario-RegexpAssemble), released on 2016-02-11.
+This document describes version 0.03 of Bencher::Scenario::RegexpAssemble (from Perl distribution Bencher-Scenario-RegexpAssemble), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -75,11 +75,15 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Regexp::Assemble> 0.36
+L<Regexp::Assemble> 0.37
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -135,44 +139,45 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m RegexpAssemble >>):
 
- +------------------+----------+-----------+-----------+---------+---------+
- | participant      | dataset  | rate (/s) | time (ms) | errors  | samples |
- +------------------+----------+-----------+-----------+---------+---------+
- | assemble-with-ra | 10000str | 1.8       | 5.6e+02   | 0.0019  | 22      |
- | assemble-raw     | 10000str | 17        | 58        | 0.00013 | 20      |
- | assemble-with-ra | 1000str  | 19        | 52        | 0.00019 | 20      |
- | assemble-raw     | 1000str  | 192       | 5.22      | 3.6e-06 | 20      |
- | assemble-with-ra | 100str   | 2e+02     | 4.9       | 2e-05   | 20      |
- | assemble-with-ra | 10str    | 2e+03     | 0.5       | 9.6e-06 | 20      |
- | assemble-raw     | 100str   | 1.9e+03   | 0.51      | 5.9e-07 | 28      |
- | assemble-raw     | 10str    | 1.6e+04   | 0.062     | 1e-07   | 22      |
- | match-with-ra    | 10000str | 3.69e+05  | 0.00271   | 2.5e-09 | 20      |
- | match-with-ra    | 1000str  | 3.99e+05  | 0.00251   | 8.3e-10 | 20      |
- | match-with-ra    | 100str   | 4.9e+05   | 0.002     | 3.3e-09 | 20      |
- | match-with-ra    | 10str    | 1.8e+06   | 0.00057   | 3.5e-09 | 31      |
- | match-raw        | 10000str | 2.5e+06   | 0.0004    | 8.1e-10 | 21      |
- | match-raw        | 1000str  | 2.6e+06   | 0.00039   | 8.3e-10 | 20      |
- | match-raw        | 100str   | 2.62e+06  | 0.000382  | 1.7e-10 | 31      |
- | match-raw        | 10str    | 2.9e+06   | 0.00035   | 8.3e-10 | 20      |
- +------------------+----------+-----------+-----------+---------+---------+
+ #table1#
+ +------------------+----------+-----------+---------------+------------+-----------+---------+
+ | participant      | dataset  | rate (/s) |   time (ms)   | vs_slowest |  errors   | samples |
+ +------------------+----------+-----------+---------------+------------+-----------+---------+
+ | assemble-with-ra | 10000str |       2.1 | 470           |        1   |   0.0013  |      20 |
+ | assemble-raw     | 10000str |      18   |  56           |        8.3 |   0.00014 |      20 |
+ | assemble-with-ra | 1000str  |      22   |  46           |       10   |   0.00027 |      21 |
+ | assemble-raw     | 1000str  |     200   |   5           |       90   | 6.7e-05   |      20 |
+ | assemble-with-ra | 100str   |     250   |   4           |      120   | 3.2e-05   |      20 |
+ | assemble-raw     | 100str   |    2000   |   0.5         |      900   | 7.8e-06   |      20 |
+ | assemble-with-ra | 10str    |    2300   |   0.44        |     1100   |   4e-06   |      20 |
+ | assemble-raw     | 10str    |   18000   |   0.055       |     8500   | 9.5e-08   |      25 |
+ | match-with-ra    | 10000str |  400000   |   0.003       |   200000   | 3.8e-08   |      20 |
+ | match-with-ra    | 1000str  |  455000   |   0.0022      |   212000   | 8.1e-10   |      21 |
+ | match-with-ra    | 100str   |  707000   |   0.00142     |   330000   | 4.7e-10   |      20 |
+ | match-with-ra    | 10str    | 1820000   |   0.000551    |   847000   |   2e-10   |      22 |
+ | match-raw        | 1000str  | 2480630   |   0.000403123 |  1157140   |   0       |      20 |
+ | match-raw        | 10000str | 2600000   |   0.000385    |  1210000   | 1.8e-10   |      30 |
+ | match-raw        | 100str   | 2630000   |   0.00038     |  1230000   | 2.1e-10   |      20 |
+ | match-raw        | 10str    | 2650000   |   0.000377    |  1240000   | 2.1e-10   |      20 |
+ +------------------+----------+-----------+---------------+------------+-----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m RegexpAssemble --module-startup >>):
 
- +---------------------+-----------+------------------------+---------+---------+
- | participant         | time (ms) | mod_overhead_time (ms) | errors  | samples |
- +---------------------+-----------+------------------------+---------+---------+
- | Regexp::Assemble    | 28        | 23                     | 7.6e-05 | 20      |
- | perl -e1 (baseline) | 5         | 0                      | 5.6e-05 | 21      |
- +---------------------+-----------+------------------------+---------+---------+
+ #table2#
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ | Regexp::Assemble    | 0.82                         | 4.1                | 16             |      27   |                   19.9 |        1   |   0.00011 |      20 |
+ | perl -e1 (baseline) | 3.7                          | 7.4                | 25             |       7.1 |                    0   |        3.8 | 1.3e-05   |      20 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -196,7 +201,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
